pub struct UseIdleHandle { /* private fields */ }Expand description
State handle for the use_idle hook.
Implementations
Sourceimpl UseIdleHandle
impl UseIdleHandle
Sourcepub fn reset_idle(&self)
pub fn reset_idle(&self)
Manually reset the idle timer, marking the user as active.
Sourcepub fn last_active(&self) -> Option<f64>
pub fn last_active(&self) -> Option<f64>
Get the timestamp of the last user activity, if available.