pub struct UseStartTypingOptions {
pub event_type: Cow<'static, str>,
pub check_editable: bool,
pub check_modifiers: bool,
pub key_filter: Option<Box<dyn Fn(&str) -> bool>>,
}Fields
event_type: Cow<'static, str>The keyboard event type to listen for. Default: “keydown”
check_editable: boolWhether to check for editable elements. Default: true
check_modifiers: boolWhether to check for modifier keys. Default: true
key_filter: Option<Box<dyn Fn(&str) -> bool>>Custom function to determine if a key should trigger the callback. If not provided, defaults to checking if the key is alphanumeric.